/*  Copyright (c) 2007-2008 Tomasz Moń <desowin@gmail.com>
 *  Copyright (c) 2004 Artur Gajda
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; under version 3 of the License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses>.
 */

#include <gtk/gtk.h>
#include <locale.h>
#include <libintl.h>
#include <getopt.h>
#include <sys/utsname.h>
#include "riv.h"
#include "net.h"
#include "ui.h"
#include "conf.h"
#include "lista.h"
#include "ui_priv.h"
#include "autoaway.h"

gchar *os_name = NULL;

int main(int argc, char *argv[]) {
    int c;
    gchar *nick = NULL;
    gchar *user = NULL;
    gint port = -1;
    while (1) {
        static struct option long_options[] = {
            {"nick", required_argument, 0, 'n'},
            {"user", required_argument, 0, 'u'},
            {"port", required_argument, 0, 'p'},
            {0, 0, 0, 0}
        };
        int option_index = 0;
        c = getopt_long(argc, argv, "n:u:p:", long_options, &option_index);
        if (c == -1)
            break;

        switch (c) {
            case 'n':
               nick = optarg;
               break;
            case 'u':
               user = optarg;
               break;
            case 'p':
               if (optarg)
                   port = atoi(optarg);
               break;
            case '?':
               /* unknown command line option; getopt_long notified user */
               break;
            default:
               abort();
        }
    }

    struct utsname name;
    if (uname(&name) != -1)
        os_name = g_strdup_printf("%s %s", name.sysname, name.release);
    else
        os_name = g_strdup("Unknown");

    g_thread_init(NULL);
    gdk_threads_init();

    gtk_init(&argc, &argv);

    setlocale(LC_ALL, "");
    bindtextdomain(PACKAGE, LOCALEDIR);
    bind_textdomain_codeset(PACKAGE, "UTF-8");
    textdomain(PACKAGE);

    parse_config();
    if (nick) { if (conf.nick) g_free(conf.nick); conf.nick = g_strndup(nick, 29); }
    if (user) { if (conf.user) g_free(conf.user); conf.user = g_strndup(user, 31); }
    if (port > 0) { conf.port = port; }

    lista_init();
    glowne_okno();
#ifdef HAVE_SCRNSAVER
    autoaway_start();
#endif
    if (net_start()) return -1;

    gtk_main();

    save_config();
    g_free(os_name);
    return 0;
}

void griv_quit() {
    send_quit();
    GList *iter;
    for (iter = priv_lista; iter; iter = g_list_next(iter)) {
        PRIV *priv = (PRIV*) iter->data;
        g_free(priv->nick);
        g_free(priv);
    }
#ifdef HAVE_SCRNSAVER
    autoaway_stop();
#endif
    gtk_main_quit();
}

